==> haskell-snap-core-1.0.3.2-40-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-core
version: 1.0.3.2
id: snap-core-1.0.3.2-DF7qmmSeYDs964KQRiBAcS
key: snap-core-1.0.3.2-DF7qmmSeYDs964KQRiBAcS
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    This library contains the core definitions and types for the Snap framework,
    including:
    .
    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)
    .
    2. A monad for programming web handlers called \"Snap\", which allows:
    .
    * Stateful access to the HTTP request and response objects
    .
    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together
    .
    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing
    .
    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".
category: Web, Snap, IO-Streams
abi: 1768b0ab571c05c33615d61143847fbe
exposed: True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing Snap.Test
    Snap.Types.Headers Snap.Util.CORS Snap.Util.FileServe
    Snap.Util.FileUploads Snap.Util.GZip Snap.Util.Proxy
hidden-modules: Snap.Internal.Instances Snap.Internal.Routing
                Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
                Snap.Internal.Util.FileServe Snap.Internal.Util.FileUploads
import-dirs: /usr/lib/ghc-8.6.3/site-local/snap-core-1.0.3.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/snap-core-1.0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/snap-core-1.0.3.2
hs-libraries: HSsnap-core-1.0.3.2-DF7qmmSeYDs964KQRiBAcS
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    attoparsec-0.13.2.2-BKfIbjnWW4NITXC0apvm49 base-4.12.0.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    io-streams-1.5.0.1-HtnK8bnjFlpgXb0YwqMOU
    lifted-base-0.2.3.12-2GU9aUuznnv3pGQUmhiVqB
    monad-control-1.0.2.3-2zhblvoGozsIFfDVW4DMdn mtl-2.2.2
    network-2.7.0.2-l7ToO0nOP7DBjiP2hy2PR
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    readable-0.3.1-7I5EIROpRuwBi3cHo2WBVY
    regex-posix-0.95.2-jmiKTXBn5tB7yYph2GqnC text-1.2.3.1 time-1.8.0.2
    transformers-0.5.5.0
    transformers-base-0.4.5.2-GVqlM7MFCpoHJlEFRaTwrG
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unordered-containers-0.2.10.0-HO72tBDce9GHcBPxpae42I
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html: /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-core-1.0.3.2-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-core
version: 1.0.3.2
id: snap-core-1.0.3.2-CLNrilbe0T4FZSC4jcklPJ
key: snap-core-1.0.3.2-CLNrilbe0T4FZSC4jcklPJ
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    This library contains the core definitions and types for the Snap framework,
    including:
    .
    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)
    .
    2. A monad for programming web handlers called \"Snap\", which allows:
    .
    * Stateful access to the HTTP request and response objects
    .
    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together
    .
    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing
    .
    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".
category: Web, Snap, IO-Streams
abi: 5c5dfc02b7d29466662ab2220a0ef72a
exposed: True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing Snap.Test
    Snap.Types.Headers Snap.Util.CORS Snap.Util.FileServe
    Snap.Util.FileUploads Snap.Util.GZip Snap.Util.Proxy
hidden-modules: Snap.Internal.Instances Snap.Internal.Routing
                Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
                Snap.Internal.Util.FileServe Snap.Internal.Util.FileUploads
import-dirs: /usr/lib/ghc-8.6.3/site-local/snap-core-1.0.3.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/snap-core-1.0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/snap-core-1.0.3.2
hs-libraries: HSsnap-core-1.0.3.2-CLNrilbe0T4FZSC4jcklPJ
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    attoparsec-0.13.2.2-Jk4D4QRG8ZrHQCpZMillSF base-4.12.0.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    io-streams-1.5.0.1-5CvsJRyB8g0HKK46CptmId
    lifted-base-0.2.3.12-AWdC50FZP7w20am3hipRIQ
    monad-control-1.0.2.3-C7Mt0wi6Itk30zmrdYvypZ mtl-2.2.2
    network-2.7.0.2-LBw9vnb0Msk5Ad9gKMihTx
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    readable-0.3.1-7I5EIROpRuwBi3cHo2WBVY
    regex-posix-0.95.2-jmiKTXBn5tB7yYph2GqnC text-1.2.3.1 time-1.8.0.2
    transformers-0.5.5.0
    transformers-base-0.4.5.2-CYvZwiYe2CEFBvY3nUdZ2C
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unordered-containers-0.2.10.0-6u5qZnIDidK2MmAyNc87rJ
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html: /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
